/*=============================================================================
vitalnix/accdb - User Management Suite - Unified Account Database
userdel.c - Delete a user account and related files
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003
  -- License restrictions apply (Dual FAL/GPL2).
  -- For details see doc/FAL.txt and doc/GPL2.txt.
=============================================================================*/
#include <errno.h>
#include <popt.h>
#include <stdio.h>
#include <string.h>

#include <accdb.h>
#include "sysprog/shared.h"

typedef unsigned char byte;

enum {
  E_SUCCESS = 0,
  E_OTHER,       // other error, see errno
  E_OPEN,        // unable to open back-end module or DB
  E_NOEXIST,     // user does not exist
  E_UPDATE,      // db->userdel() did not return ok
  E_CLOSE,       // db->close() did not return ok
};

struct {
  char *lname;
  int rm_home;
} opt;

static int get_options(int *, const char ***);

static char *module_path = "*";

//-----------------------------------------------------------------------------
int main(int argc, char **argv) {
  struct accdb_module *db;
  int eax, rv = E_SUCCESS;

  if(!(eax = get_options(&argc, (const char ***)&argv))) { return E_OTHER; }
  opt.lname = *argv;

  if((db = accdb_load(module_path)) == NULL) {
    fprintf(stderr, "Could not load ACCDB back-end module \"%s\": %s\n",
     module_path, strerror(errno));
    return E_OPEN;
  }

  db->open(&db->state);
  db->close(db->state);
  accdb_unload(db);
  return rv;
}

//-----------------------------------------------------------------------------
static int get_options(int *argc, const char ***argv) {
  static const char *_empty_argv[] = {NULL};
  const struct poptOption options_table[] = {
    // New, accdb-userdel options
    {NULL, 'R', POPT_ARG_VAL, &opt.rm_home, 2,
     "Remove: home directory, mail spool and cron spool tabs", NULL},

    // Default options
    {NULL, 'r', POPT_ARG_NONE, &opt.rm_home, 1,
     "Remove: home directory and mail spool", NULL},

    POPT_AUTOHELP
    POPT_TABLEEND
  };

  poptContext ctx;
  const char **args;
  int c, argk;

  ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
  while((c = poptGetNextOpt(ctx)) >= 0);
  if(c < -1) {
    fprintf(stderr, "%s: %s\n", poptBadOption(ctx, 0), poptStrerror(c));
    return 0;
  }

  if((args = poptGetArgs(ctx)) != NULL) {
    argk = Sh_count_args(args);
    poptDupArgv(argk, args, argc, argv);
  } else {
    *argc = 0;
    *argv = _empty_argv;
  }

  if(args == NULL || *args == NULL) {
    // loginname is mandatory
    poptPrintUsage(ctx, stderr, 0);
    return 0;
  }

  poptFreeContext(ctx);
  return 1;
}

//==[ End of file ]============================================================
